@@ -10,6 +10,14 @@ pub struct Base<T> {
     constant: T,
 }
 
+use core::ops::Deref;
+impl<T> Deref for Base<T>{
+    type Target = T;
+    fn deref(&self) -> &Self::Target{
+        &self.constant
+    }
+}
+
 impl<T> Attribute<T> for Base<T>
 where
     T: GLType,
@@ -17,7 +25,7 @@ where
     fn index(&self) -> &Index {
         &self.index
     }
-    fn constant(&mut self, mut constant: T) -> T {
+    fn swap(&mut self, mut constant: T) -> T {
         use core::mem::swap;
         swap(&mut self.constant, &mut constant);
         self.constant.constant(&*self.gl, self.index);
@@ -102,14 +110,14 @@ where
         T::compatible(&attribute).map_err(Error::Attribute)?;
 
         use core::mem::MaybeUninit;
-        let mut base = Base {
+        let mut base = Base::<T> {
             index,
             name,
             gl,
             constant: unsafe { MaybeUninit::uninit().assume_init() },
         };
 
-        base.constant(self);
+        base.swap(self);
 
         Ok(base)
     }
