@@ -39,7 +39,7 @@ pub trait Attribute<T> {
     ///The index/location of the attribute.
     fn index(&self) -> &Index;
     ///Change the default value of the attibute, returnes the old value.
-    fn constant(&mut self, constant: T) -> T;
+    fn swap(&mut self, constant: T) -> T;
     ///Construct a attribute pointer.
     fn pointer<'attribute>(
         &'attribute mut self,
