@@ -9,6 +9,14 @@ pub struct Base<T> {
     value: T,
 }
 
+use core::ops::Deref;
+impl<T> Deref for Base<T>{
+    type Target = T;
+    fn deref(&self) -> &Self::Target{
+        &self.value
+    }
+}
+
 #[derive(Debug, PartialEq, Eq)]
 pub enum Error {
     GLError(super::super::context::Error),
@@ -36,7 +44,7 @@ where
     fn index(&self) -> &Index {
         &self.index
     }
-    fn value(&mut self, mut value: T) -> T {
+    fn swap(&mut self, mut value: T) -> T {
         use core::mem::swap;
         value.send(&*self.gl, &self.index);
         swap(&mut self.value, &mut value);
@@ -73,14 +81,14 @@ where
         T::compatible(&info).map_err(Error::Type)?;
 
         use core::mem::MaybeUninit;
-        let mut base = Base {
+        let mut base = Base::<T> {
             index,
             name,
             gl,
             value: unsafe { MaybeUninit::uninit().assume_init() },
         };
 
-        base.value(self);
+        base.swap(self);
 
         Ok(base)
     }
