@@ -47,7 +47,7 @@ pub trait ToUniform {
 
 pub trait Uniform<T> {
     fn index(&self) -> &Index;
-    fn value(&mut self, value: T) -> T;
+    fn swap(&mut self, value: T) -> T;
 }
 
 use super::NoneError;
